Learn R Programming

NBDCtools (version 1.0.2)

transf_time_to_hms: Convert time columns to hms format

Description

This function converts time columns to hms format.

Usage

transf_time_to_hms(data, study, release = "latest")

Value

A tibble with time columns converted to hms format.

Arguments

data

tibble. The data to be converted.

study

character. NBDC study (One of "abcd" or "hbcd").

release

character. Release version (Default: "latest").

Details

The input data with time columns are expected to have character format of "HH:MM:SS". If it is not in this format, the function will return NA for that row.

Examples

Run this code
if (FALSE) {
transf_time_to_hms(data)
}

Run the code above in your browser using DataLab