A tibble with time columns converted to hms format.
Arguments
data
tibble. The data to be converted.
study
character. NBDC study (One of "abcd" or "hbcd").
release
character. Release version (Default: "latest").
Details
The input data with time columns are expected to have character format
of "HH:MM:SS". If it is not in this format, the function will return NA
for that row.